<?php

namespace Drupal\tmgmt_morningside\Controller;

use Drupal\Core\Controller\ControllerBase;

/**
 * Default controller for the tmgmt_morningside module.
 */
class DefaultController extends ControllerBase {

  /**
   * This function called from CRON to update request status.
   */
  public function updateRequestStatus() {

    $translator = $this->getTranslators();
    $connection = \Drupal::database();
    $result = $connection->select('tmgmt_morningside_requests', 'mr')
      ->fields('mr', ['RequestNo', 'RequestStatus', 'RequestType'])
      ->execute()
      ->fetchAll();
    foreach ($result as $request) {

      switch ($request->RequestStatus) {
        case 'Quote Pending':
        case 'Order Pending':
        case 'In Preparation':
        case 'Pending':
        case 'New (auto)':
        case 'Changed into quote':
        case 'Quote in Progress':

          $translator->getPlugin()
            ->updateRequest($translator, $request->RequestNo, $request->RequestType);
          break;

        case 'Rejected':
        case 'Changed into order':
        case 'Canceled':
        default:
      }
    }
  }

  /**
   * This function called from CRON to update quote status.
   */
  public function updateQuoteStatus() {
    $translator = $this->getTranslators();
    $connection = \Drupal::database();
    $result = $connection->select('tmgmt_morningside_quotes', 'mq')
      ->fields('mq', ['QuoteNo', 'QuoteStatus'])
      ->execute()
      ->fetchAll();

    foreach ($result as $quote) {

      switch ($quote->QuoteStatus) {
        case 'Quote in Progress':
        case 'New':
        case 'Quote Complete':
        case 'Accepted':
        case 'Quote Approved':
        case 'Rejected':
          $translator->getPlugin()->updateQuote($translator, $quote->QuoteNo);
          break;

        case 'Quote Revised';
        case 'Quote Canceled':
        case 'Check Clearance':
        case 'Quote Expired':
        default:
      }
    }
  }

  /**
   * This function called from CRON to update order status.
   */
  public function updateOrderStatus() {
    $translator = $this->getTranslators();
    $connection = \Drupal::database();
    $result = $connection->select('tmgmt_morningside_orders', 'mo')
      ->fields('mo', ['OrderNo', 'OrderStatus', 'RequestID'])
      ->execute()
      ->fetchAll();
    foreach ($result as $order) {
      switch ($order->OrderStatus) {
        case "Quote Moved to Order":
        case "Order in Progress":
        case "Active":
          $translator->getPlugin()->updateOrder($translator, $order->OrderNo);
          break;

        case "Order Complete":
          $orderNo = $order->OrderNo;
          $requestID = $order->RequestID;
          $fileList = $translator->getPlugin()->getFileList($translator, $orderNo);
          if ($fileList) {
            foreach ($fileList as $file) {
              $fileName = str_replace("\\\\", "\\", $file);
              $downloadedFile = $translator->getPlugin()->downloadFile($translator, $orderNo, $requestID, $fileName);
              print_r($downloadedFile->getFileUri());
              if ($downloadedFile) {
                $translator->getPlugin()->pushContent($translator, $downloadedFile, $requestID, $orderNo);
              }
            }
          }
          break;

        case "Archived":
        case "Archivable":
        default:
      }
    }
  }

  /**
   * This function is used for get translator.
   */
  public function getTranslators() {
    $translators = \Drupal::entityManager()->getStorage('tmgmt_translator')->loadByProperties(['plugin' => 'morningside']);

    if (!$translators) {
      return;
    }

    foreach ($translators as $translator) {
      // Receive all processed translations.
      return $translator;
    }
  }

}
